==> qt-creator-opensource-src-4.0.0.zip: qt-creator-opensource-src-4.0.0/src/plugins/texteditor/codeassist/quickfixassistprovider.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#ifndef QUICKFIXASSISTPROVIDER_H
#define QUICKFIXASSISTPROVIDER_H

#include "iassistprovider.h"

#include <QList>

namespace TextEditor {

class QuickFixFactory;

class TEXTEDITOR_EXPORT QuickFixAssistProvider : public IAssistProvider
{
    Q_OBJECT

public:
    QuickFixAssistProvider();
    ~QuickFixAssistProvider();

    virtual QList<QuickFixFactory *> quickFixFactories() const;
};

} // TextEditor

#endif // QUICKFIXASSISTPROVIDER_H

==> qt-creator-opensource-src-4.4.0.zip: qt-creator-opensource-src-4.4.0/src/plugins/texteditor/codeassist/quickfixassistprovider.h <==
/****************************************************************************
**
** Copyright (C) 2016 The Qt Company Ltd.
** Contact: https://www.qt.io/licensing/
**
** This file is part of Qt Creator.
**
** Commercial License Usage
** Licensees holding valid commercial Qt licenses may use this file in
** accordance with the commercial license agreement provided with the
** Software or, alternatively, in accordance with the terms contained in
** a written agreement between you and The Qt Company. For licensing terms
** and conditions see https://www.qt.io/terms-conditions. For further
** information use the contact form at https://www.qt.io/contact-us.
**
** GNU General Public License Usage
** Alternatively, this file may be used under the terms of the GNU
** General Public License version 3 as published by the Free Software
** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
** included in the packaging of this file. Please review the following
** information to ensure the GNU General Public License requirements will
** be met: https://www.gnu.org/licenses/gpl-3.0.html.
**
****************************************************************************/

#pragma once

#include "iassistprovider.h"

#include <QList>

namespace TextEditor {

class QuickFixFactory;

class TEXTEDITOR_EXPORT QuickFixAssistProvider : public IAssistProvider
{
    Q_OBJECT

public:
    QuickFixAssistProvider(QObject *parent = 0);
    ~QuickFixAssistProvider();

    virtual QList<QuickFixFactory *> quickFixFactories() const;
};

} // TextEditor
